==> squishyplanet-0.1.0.tar.gz: squishyplanet-0.1.0/README.md <==
# squishyplanet


[![Documentation Status](https://readthedocs.org/projects/squishyplanet/badge/?version=latest)](https://squishyplanet.readthedocs.io/en/latest/?badge=latest)
![Build Status](https://github.com/ben-cassese/squishyplanet/actions/workflows/tests.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/ben-cassese/squishyplanet/badge.svg?branch=main&service=github)](https://coveralls.io/github/ben-cassese/squishyplanet?branch=main)
![PyPI - Version](https://img.shields.io/pypi/v/squishyplanet)

A package for modeling non-spherical exoplanets.

![image](docs/_static/media/videos/_static/480p15/Banner_ManimCE_v0.17.3.gif)

## Documentation

The docs for ``squishyplanet`` are hosted on [Read the Docs](https://squishyplanet.readthedocs.io/en/latest/). See those for installation instructions, example usage, and API documentation.

## Installation

You can install ``squishyplanet`` from PyPI with pip:

```bash
python -m pip install squishyplanet
```

See the [installation instructions](https://squishyplanet.readthedocs.io/en/latest/installation.html) for more details.

## Attribution and License

 [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[hopefully joss badge]

``squishyplanet`` is made freely available under the MIT License. If you use this code in your research, please cite the accompanying JOSS paper. The citation information will be updated once the paper is submitted/accepted.

```
@article{
    squishyplanet,
    doi = {},
    url = {},
    year = 2024,
    month = {},
    publisher = {},
    volume = {},
    number = {},
    author = {},
    title = {squishyplanet: non-spherical exoplanets in JAX},
    journal = {}
}
```

==> squishyplanet-0.1.2.tar.gz: squishyplanet-0.1.2/README.md <==
# squishyplanet


[![Documentation Status](https://readthedocs.org/projects/squishyplanet/badge/?version=latest)](https://squishyplanet.readthedocs.io/en/latest/?badge=latest)
![Build Status](https://github.com/ben-cassese/squishyplanet/actions/workflows/tests.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/ben-cassese/squishyplanet/badge.svg?branch=main&service=github)](https://coveralls.io/github/ben-cassese/squishyplanet?branch=main)
![PyPI - Version](https://img.shields.io/pypi/v/squishyplanet)

A package for modeling non-spherical exoplanets.

![image](docs/_static/media/videos/_static/480p15/Banner_ManimCE_v0.17.3.gif)

## Documentation

The docs for ``squishyplanet`` are hosted on [Read the Docs](https://squishyplanet.readthedocs.io/en/latest/). See those for installation instructions, example usage, and API documentation.

## Installation

You can install ``squishyplanet`` from PyPI with pip:

```bash
python -m pip install squishyplanet
```

See the [installation instructions](https://squishyplanet.readthedocs.io/en/latest/installation.html) for more details.

## Attribution and License

 [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[hopefully joss badge]

``squishyplanet`` is made freely available under the MIT License. If you use this code in your research, please cite the accompanying JOSS paper. The citation information will be updated once the paper is submitted/accepted.

```
@article{
    squishyplanet,
    doi = {},
    url = {},
    year = 2024,
    month = {},
    publisher = {},
    volume = {},
    number = {},
    author = {},
    title = {squishyplanet: modeling transits of non-spherical exoplanets in JAX},
    journal = {}
}
```
